@@ -4,7 +4,7 @@ f = Foo()
 b = Bar(f)
 
 if b.extension() != f.extension():
-  raise RuntimeError
+    raise RuntimeError
 
 
 b = CBase()
@@ -12,13 +12,21 @@ d = CDerived()
 p = CPtr()
 
 if b.bar() != p.bar():
-  raise RuntimeError
+    raise RuntimeError
 
 if d.foo() != p.foo():
-  raise RuntimeError
+    raise RuntimeError
 
 if b.hello() != p.hello():
-  raise RuntimeError
+    raise RuntimeError
 
 
+d = DFoo()
 
+dp = DPtrFoo(d)
+
+if d.SExt(1) != dp.SExt(1):
+    raise RuntimeError
+
+if d.Ext(1) != dp.Ext(1):
+    raise RuntimeError
